@@ -1,5 +1,5 @@
 from functools import lru_cache
-from typing import Optional
+from typing import Dict, Optional
 
 from pydantic import BaseSettings, Field
 
@@ -7,7 +7,7 @@ from pydantic import BaseSettings, Field
 class Config(BaseSettings):
     port: int = Field(4000, env="PORT")
     store_path: str = Field("debouncer.db", env="STORE_PATH")
-    auth_key: Optional[str] = Field(None, env="AUTH_KEY")
+    credentials: Optional[Dict[str, str]] = Field(None, env="CREDENTIALS")
 
 
 @lru_cache()
